@charset "UTF-8";
table.phpdebugbar-widgets-languageStrings {
  width: 100%;
  margin-top: 5px;
  margin-left: 5px;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  line-height: 1.3em;
}

table.phpdebugbar-widgets-languageStrings th {
  border-bottom: 1px solid #000;
}

table.phpdebugbar-widgets-languageStrings table.phpdebugbar-widgets-callstack {
  border-collapse: collapse;
  border: 1px solid #ddd;
  width: 100%;
  margin: 10px;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  display: none;
}

table.phpdebugbar-widgets-languageStrings table.phpdebugbar-widgets-callstack tr.caller {
  background-color: #fff9b6;
}

table.phpdebugbar-widgets-languageStrings table.phpdebugbar-widgets-callstack tbody tr:hover {
  background-color: #eee;
}

table.phpdebugbar-widgets-languageStrings table.phpdebugbar-widgets-callstack th {
  font-weight: bold;
}

table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye, table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye-dash {
  color: #888;
  margin-left: 8px;
}

table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye-dash {
  color: #000;
  background-color: #eee;
}

table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye:before, table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye-dash:before {
  margin-right: 4px;
  font-family: "Font Awesome 6 Free";
}

table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye:before {
  content: "";
}

table.phpdebugbar-widgets-languageStrings span.phpdebugbar-widgets-eye-dash:before {
  content: "";
}
