@charset "UTF-8";
table.phpdebugbar-widgets-info {
  width: 75%;
  margin-top: 5px;
  margin-left: 5px;
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, Courier, monospace;
  line-height: 1.3em;
}

table.phpdebugbar-widgets-info td {
  border-bottom: 1px solid silver;
  padding-right: 10px;
}

table.phpdebugbar-widgets-info dt {
  float: left;
  clear: left;
  text-align: left;
  width: 30%;
  padding: .25em;
}

table.phpdebugbar-widgets-info dd {
  float: left;
  width: 60%;
  padding: .25em 0;
}

table.phpdebugbar-widgets-info dl:after {
  clear: both;
  content: "";
  display: table;
}
